{% extends 'django_cowhite_cms/base.html' %}

{% load humanize %}

{% block meta_title %}
{{ page.seo_title }}
{% endblock %}

{% block content %}
<div class='heading'>{{ page.title }}</div>

<div class='blog'>
  <div class='author-info'>Posted by {{ page.author.first_name }} {{ page.created_at|naturaltime }}</div>
  {% if page.cover_image %}
  <div class='cover-image'>
    <img src="{{ page.cover_image.url }}" />
  </div>
  {% endif %}

  <div class='post-content'>
    {{ page.content|safe }}
  </div>
</div>

{% if disqus_short_name %}
<div id="disqus_thread"></div>
<script>
    /**
     *  RECOMMENDED CONFIGURATION VARIABLES: EDIT AND UNCOMMENT
     *  THE SECTION BELOW TO INSERT DYNAMIC VALUES FROM YOUR
     *  PLATFORM OR CMS.
     *
     *  LEARN WHY DEFINING THESE VARIABLES IS IMPORTANT:
     *  https://disqus.com/admin/universalcode/#configuration-variables
     */
    /*
    var disqus_config = function () {
        // Replace PAGE_URL with your page's canonical URL variable
        this.page.url = PAGE_URL;

        // Replace PAGE_IDENTIFIER with your page's unique identifier variable
        this.page.identifier = PAGE_IDENTIFIER;
    };
    */

    (function() {  // REQUIRED CONFIGURATION VARIABLE: EDIT THE SHORTNAME BELOW
        var d = document, s = d.createElement('script');

        // IMPORTANT: Replace EXAMPLE with your forum shortname!
        s.src = 'https://{{ disqus_short_name }}.disqus.com/embed.js';

        s.setAttribute('data-timestamp', +new Date());
        (d.head || d.body).appendChild(s);
    })();
</script>
<noscript>
    Please enable JavaScript to view the
    <a href="https://disqus.com/?ref_noscript" rel="nofollow">
        comments powered by Disqus.
    </a>
</noscript>
{% endif %}
{% endblock %}