# -*- coding: utf-8 -*-
# Generated by Django 1.11.11 on 2018-06-17 18:02
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_cowhite_cms', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='page',
            name='categories',
        ),
        migrations.DeleteModel(
            name='Category',
        ),
    ]
