<!DOCTYPE html>
<html>
<head>
  <title>{% block meta_title %}{% endblock %} | Cowhite Software</title>

  <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}django_cowhite_cms/lib/bootstrap-4.1.1-dist/css/bootstrap.min.css">
  <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}django_cowhite_cms/css/style.css">
</head>
<body>
  {% include "django_cowhite_cms/includes/navbar.html" %}

  <div class='container' id="main-content">
    {% block content %}{% endblock %}
  </div>

  <footer class='footer'>
    <div class='container'>
      <div class='copyright'>
        © {% now 'Y' %} Cowhite Software Pvt Ltd
      </div>
    </div>
  </footer>

  <script type="text/javascript" src="{{ STATIC_URL }}django_cowhite_cms/lib/js/jquery.min.js"></script>
  <script type="text/javascript" src="{{ STATIC_URL }}django_cowhite_cms/lib/bootstrap-4.1.1-dist/js/bootstrap.bundle.min.js"></script>

  {% block js %}{% endblock %}

</body>
</html>